'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _buildJs = require('./build.js');

var _buildJs2 = _interopRequireDefault(_buildJs);

var _blessedContrib = require('blessed-contrib');

var _blessedContrib2 = _interopRequireDefault(_blessedContrib);

var _blessed = require('blessed');

var _blessed2 = _interopRequireDefault(_blessed);

var request = require('request');

var colors = require('colors/safe');
function buildRow(build) {
  var number = build.number;
  var displayTime = build.displayTime;
  var result = build.result;
  var commit = build.commit;
  var committerName = commit.committerName;
  var message = commit.message;
  var shortSha = commit.shortSha;
  var branch = commit.branch;

  var color = colors.black;
  switch (result) {
    case 'SUCCESS':
      color = colors.green;
      break;
    case 'FAILURE':
      color = colors.red;
      break;
    case 'ABORTED':
      color = colors.grey;
      break;
    default:
      color = colors.yellow;
      break;
  }
  var cols = [displayTime, result, branch, committerName, message, shortSha].map(function (col) {
    return color(col);
  });
  return [number + ''].concat(cols);
}
function buildHistoryWidget(title, url, screen, inputBuilds, onBack) {
  var builds = [];
  builds.push(['number', 'Ago', 'Result', 'Branch', 'Commiter', 'Message', 'Sha']);
  inputBuilds.forEach(function (build) {
    return builds.push(buildRow(build));
  });
  var table = _blessed2['default'].ListTable({
    parent: screen,
    screen: screen,
    width: '100%',
    height: '100%',
    border: {
      type: 'line',
      left: true,
      top: true,
      right: false,
      bottom: false
    },
    align: 'center',
    tags: true,
    keys: true,
    vi: true,
    mouse: true,
    noCellBorders: true,
    style: {
      header: {
        fg: 'blue',
        bold: true
      },
      cell: {
        fg: 'white',
        selected: {
          bg: 'blue'
        }
      }
    },
    rows: builds
  });
  table.on('select', function (item) {
    var number = item.parent.rows[item.parent.selected][0];
    _buildJs2['default'](url, screen, number, onBack);
  });
  table.focus();
}

exports['default'] = function (title, url, screen, onBack) {
  request({
    uri: url + 'api/json/',
    qs: {
      tree: "appData[info[buildHistoryTabs,builds[*,commit[*],cause[*],parameters[*]]]]",
      branchTab: 'All',
      count: 50
    }
  }, function (error, response, body) {
    if (!error && response.statusCode == 200) {
      var builds = JSON.parse(body)['appData']['info']['builds'];
      buildHistoryWidget(title, url, screen, builds, onBack);
      screen.render();
    }
  });
};

module.exports = exports['default'];